==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/RUBA.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+12)
#define CT_v201	((void*)startLabel+40)
#define F0_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+48)
#define FN_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+76)
#define CT_v205	((void*)startLabel+128)
#define CF_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+136)
#define CT_v212	((void*)startLabel+312)
#define FN_LAMBDA197	((void*)startLabel+364)
#define CT_v216	((void*)startLabel+416)
#define F0_LAMBDA197	((void*)startLabel+424)
#define PP_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+448)
#define PC_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+448)
#define ST_v203	((void*)startLabel+448)
#define PP_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+469)
#define PC_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+469)
#define ST_v200	((void*)startLabel+469)
#define ST_v207	((void*)startLabel+492)
#define PP_LAMBDA197	((void*)startLabel+510)
#define PC_LAMBDA197	((void*)startLabel+510)
#define ST_v214	((void*)startLabel+510)
#define PS_v204	((void*)startLabel+536)
#define PS_v202	((void*)startLabel+548)
#define PS_v209	((void*)startLabel+560)
#define PS_v208	((void*)startLabel+572)
#define PS_v206	((void*)startLabel+584)
#define PS_v211	((void*)startLabel+596)
#define PS_v210	((void*)startLabel+608)
#define PS_v199	((void*)startLabel+620)
#define PS_v215	((void*)startLabel+632)
#define PS_v213	((void*)startLabel+644)
void FR_NHC_46BinArray_46hs_95rUBA_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok2[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95apply2[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46BinArray[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v201)
,	/* FN_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110022
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA_35),2)
, useLabel(PS_v199)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v205)
,	/* FN_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v204)
, 0
, 0
, 0
, 0
, 110022
, useLabel(ST_v203)
,	/* CT_v205: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, useLabel(PS_v202)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v212)
,};
Node FN_NHC_46BinArray_46rUBA[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(18,HEAP_OFF_N1,11,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v211)
, 0
, 0
, 0
, 0
, useLabel(PS_v210)
, 0
, 0
, 0
, 0
, useLabel(PS_v209)
, 0
, 0
, 0
, 0
, useLabel(PS_v208)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v207)
,	/* CT_v212: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46BinArray_46rUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46rUBA),2)
, useLabel(PS_v206)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA197),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v216)
,	/* FN_LAMBDA197: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v215)
, 0
, 0
, 0
, 0
, 150014
, useLabel(ST_v214)
,	/* CT_v216: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA197: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA197),1)
, useLabel(PS_v213)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* PP_NHC_46BinArray_46hs_95rUBA: (byte 0) */
 	/* PC_NHC_46BinArray_46hs_95rUBA: (byte 0) */
 	/* ST_v203: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(114,85,66,65)
,	/* PP_NHC_46BinArray_46hs_95rUBA_35: (byte 1) */
 	/* PC_NHC_46BinArray_46hs_95rUBA_35: (byte 1) */
 	/* ST_v200: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,114,85,66)
, bytes2word(65,35,0,0)
,};
Node PP_NHC_46BinArray_46rUBA[] = {
 };
Node PC_NHC_46BinArray_46rUBA[] = {
 	/* ST_v207: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,114,85,66)
,	/* PP_LAMBDA197: (byte 2) */
 	/* PC_LAMBDA197: (byte 2) */
 	/* ST_v214: (byte 2) */
  bytes2word(65,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,114)
, bytes2word(85,66,65,58)
, bytes2word(49,53,58,49)
, bytes2word(52,0,0,0)
,	/* PS_v204: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95rUBA)
, useLabel(PC_NHC_46Internal_46_95mkIOok2)
,	/* PS_v202: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95rUBA)
, useLabel(PC_NHC_46BinArray_46hs_95rUBA)
,	/* PS_v209: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_NHC_46Internal_46_95apply2)
,	/* PS_v208: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_NHC_46BinArray_46hs_95rUBA)
,	/* PS_v206: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_NHC_46BinArray_46rUBA)
,	/* PS_v211: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v210: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_LAMBDA197)
,	/* PS_v199: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95rUBA_35)
, useLabel(PC_NHC_46BinArray_46hs_95rUBA_35)
,	/* PS_v215: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA197)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v213: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA197)
, useLabel(PC_LAMBDA197)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_rUBA" NHC.BinArray.hs_rUBA# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_rUBA(void*,HsInt);
#ifdef PROFILE
static SInfo pf_hs_rUBA = {"NHC.BinArray","NHC.BinArray.hs_rUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95rUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_rUBA(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_rUBA);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/RUBA.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+12)
#define CT_v205	((void*)startLabel+40)
#define F0_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+48)
#define FN_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+76)
#define CT_v209	((void*)startLabel+128)
#define CF_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+136)
#define CT_v216	((void*)startLabel+312)
#define FN_LAMBDA201	((void*)startLabel+364)
#define CT_v220	((void*)startLabel+416)
#define F0_LAMBDA201	((void*)startLabel+424)
#define PP_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+448)
#define PC_NHC_46BinArray_46hs_95rUBA	((void*)startLabel+448)
#define ST_v207	((void*)startLabel+448)
#define PP_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+469)
#define PC_NHC_46BinArray_46hs_95rUBA_35	((void*)startLabel+469)
#define ST_v204	((void*)startLabel+469)
#define ST_v211	((void*)startLabel+492)
#define PP_LAMBDA201	((void*)startLabel+510)
#define PC_LAMBDA201	((void*)startLabel+510)
#define ST_v218	((void*)startLabel+510)
#define PS_v208	((void*)startLabel+540)
#define PS_v206	((void*)startLabel+552)
#define PS_v213	((void*)startLabel+564)
#define PS_v212	((void*)startLabel+576)
#define PS_v210	((void*)startLabel+588)
#define PS_v215	((void*)startLabel+600)
#define PS_v214	((void*)startLabel+612)
#define PS_v203	((void*)startLabel+624)
#define PS_v219	((void*)startLabel+636)
#define PS_v217	((void*)startLabel+648)
void FR_NHC_46BinArray_46hs_95rUBA_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok2[];
extern Node PC_NHC_46Internal_46_95apply2[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v205)
,	/* FN_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 110001
, useLabel(ST_v204)
,	/* CT_v205: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46BinArray_46hs_95rUBA_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA_35),2)
, useLabel(PS_v203)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v209)
,	/* FN_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v208)
, 0
, 0
, 0
, 0
, 110001
, useLabel(ST_v207)
,	/* CT_v209: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95rUBA: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, useLabel(PS_v206)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46BinArray_46hs_95rUBA_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v216)
,};
Node FN_NHC_46BinArray_46rUBA[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_P1,9,HEAP_CVAL_N1,17)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,PUSH_HEAP)
, bytes2word(HEAP_CVAL_P1,10,HEAP_CVAL_N1,22)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(18,HEAP_OFF_N1,11,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v215)
, 0
, 0
, 0
, 0
, useLabel(PS_v214)
, 0
, 0
, 0
, 0
, useLabel(PS_v213)
, 0
, 0
, 0
, 0
, useLabel(PS_v212)
, 0
, 0
, 0
, 0
, 140001
, useLabel(ST_v211)
,	/* CT_v216: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46BinArray_46rUBA[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46rUBA),2)
, useLabel(PS_v210)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95rUBA))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA201),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v220)
,	/* FN_LAMBDA201: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v219)
, 0
, 0
, 0
, 0
, 150014
, useLabel(ST_v218)
,	/* CT_v220: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA201: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA201),1)
, useLabel(PS_v217)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* PP_NHC_46BinArray_46hs_95rUBA: (byte 0) */
 	/* PC_NHC_46BinArray_46hs_95rUBA: (byte 0) */
 	/* ST_v207: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(114,85,66,65)
,	/* PP_NHC_46BinArray_46hs_95rUBA_35: (byte 1) */
 	/* PC_NHC_46BinArray_46hs_95rUBA_35: (byte 1) */
 	/* ST_v204: (byte 1) */
  bytes2word(0,78,72,67)
, bytes2word(46,66,105,110)
, bytes2word(65,114,114,97)
, bytes2word(121,46,104,115)
, bytes2word(95,114,85,66)
, bytes2word(65,35,0,0)
,};
Node PP_NHC_46BinArray_46rUBA[] = {
 };
Node PC_NHC_46BinArray_46rUBA[] = {
 	/* ST_v211: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,114,85,66)
,	/* PP_LAMBDA201: (byte 2) */
 	/* PC_LAMBDA201: (byte 2) */
 	/* ST_v218: (byte 2) */
  bytes2word(65,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,114)
, bytes2word(85,66,65,58)
, bytes2word(49,53,58,49)
, bytes2word(52,45,49,53)
, bytes2word(58,50,56,0)
,	/* PS_v208: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95rUBA)
, useLabel(PC_NHC_46Internal_46_95mkIOok2)
,	/* PS_v206: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95rUBA)
, useLabel(PC_NHC_46BinArray_46hs_95rUBA)
,	/* PS_v213: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_NHC_46Internal_46_95apply2)
,	/* PS_v212: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_NHC_46BinArray_46hs_95rUBA)
,	/* PS_v210: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_NHC_46BinArray_46rUBA)
,	/* PS_v215: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v214: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46rUBA)
, useLabel(PC_LAMBDA201)
,	/* PS_v203: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95rUBA_35)
, useLabel(PC_NHC_46BinArray_46hs_95rUBA_35)
,	/* PS_v219: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA201)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v217: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA201)
, useLabel(PC_LAMBDA201)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_rUBA" NHC.BinArray.hs_rUBA# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.Int */
extern HsInt hs_rUBA(void*,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95rUBA_35 = {"NHC.BinArray","NHC.BinArray.hs_rUBA#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95rUBA_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  result = hs_rUBA(arg1,arg2);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95rUBA_35);
  C_RETURN(nodeptr);
}
